==> haskell-non-negative-0.1.2-133-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-non-negative.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 non-negative
version:              0.1.2
visibility:           public
id:                   non-negative-0.1.2-KFa286sA3bP7UwBVrqSn2D
key:                  non-negative-0.1.2-KFa286sA3bP7UwBVrqSn2D
license:              LicenseRef-GPL
maintainer:           Henning Thielemann <haskell@henning-thielemann.de>
author:               Henning Thielemann <haskell@henning-thielemann.de>
homepage:             http://code.haskell.org/~thielema/non-negative/
synopsis:             Non-negative numbers
description:
    Provides a class for non-negative numbers,
    a wrapper which can turn any ordered numeric type into a member of that class,
    and a lazy number type for non-negative numbers
    (a generalization of Peano numbers).
    This library is used by the @event-list@ package.

category:             Math
abi:                  83c393f8410f5e832deeda24f48cc5b6
exposed:              True
exposed-modules:
    Numeric.NonNegative.Chunky Numeric.NonNegative.Class
    Numeric.NonNegative.Wrapper

hidden-modules:       Numeric.NonNegative.ChunkyPrivate
import-dirs:          /usr/lib/ghc-9.0.1/site-local/non-negative-0.1.2
library-dirs:         /usr/lib/ghc-9.0.1/site-local/non-negative-0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/non-negative-0.1.2
hs-libraries:         HSnon-negative-0.1.2-KFa286sA3bP7UwBVrqSn2D
depends:
    QuickCheck-2.14.2-5cPRTtrxXz46wA1XUCyvzI base-4.15.0.0
    utility-ht-0.0.16-5oiiZ8kN3lq2kZMwJQl6fF

haddock-interfaces:
    /usr/share/doc/haskell-non-negative/html/non-negative.haddock

haddock-html:         /usr/share/doc/haskell-non-negative/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-non-negative-0.1.2-135-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-non-negative.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 non-negative
version:              0.1.2
visibility:           public
id:                   non-negative-0.1.2-CW5YJjaxAQKARAouzMF7Y2
key:                  non-negative-0.1.2-CW5YJjaxAQKARAouzMF7Y2
license:              LicenseRef-GPL
maintainer:           Henning Thielemann <haskell@henning-thielemann.de>
author:               Henning Thielemann <haskell@henning-thielemann.de>
homepage:             http://code.haskell.org/~thielema/non-negative/
synopsis:             Non-negative numbers
description:
    Provides a class for non-negative numbers,
    a wrapper which can turn any ordered numeric type into a member of that class,
    and a lazy number type for non-negative numbers
    (a generalization of Peano numbers).
    This library is used by the @event-list@ package.

category:             Math
abi:                  4524f10551f356e09fb152ec288c84ad
exposed:              True
exposed-modules:
    Numeric.NonNegative.Chunky Numeric.NonNegative.Class
    Numeric.NonNegative.Wrapper

hidden-modules:       Numeric.NonNegative.ChunkyPrivate
import-dirs:          /usr/lib/ghc-9.0.1/site-local/non-negative-0.1.2
library-dirs:         /usr/lib/ghc-9.0.1/site-local/non-negative-0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/non-negative-0.1.2
hs-libraries:         HSnon-negative-0.1.2-CW5YJjaxAQKARAouzMF7Y2
depends:
    QuickCheck-2.14.2-IrY4A8ma85dGplUSiagEJp base-4.15.0.0
    utility-ht-0.0.16-2qHyBmuJ4GNBiLr0k3smL8

haddock-interfaces:
    /usr/share/doc/haskell-non-negative/html/non-negative.haddock

haddock-html:         /usr/share/doc/haskell-non-negative/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
